#
# spec file for package apache2-mod_authn_otp
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Archie L. Cobbs <archie@dellroad.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define mod_name           mod_authn_otp
%define apxs               /usr/sbin/apxs2
%define apache_libexecdir  %(%{apxs} -q LIBEXECDIR)

Name:           apache2-%{mod_name}
Version:        1.1.7
Release:        9.1
Summary:        Apache module for one-time password authentication
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
Source:         https://s3.amazonaws.com/archie-public/mod-authn-otp/%{mod_name}-%{version}.tar.gz
Url:            http://mod-authn-otp.googlecode.com/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1100
BuildRequires:  libopenssl-devel
BuildRequires:  openssl
%else
BuildRequires:  openssl-devel
%endif

BuildRequires:  apache2-devel
Provides:       otptool = %{version}

%description
mod_authn_otp is an Apache web server module for two-factor authentication
using one-time passwords (OTP) generated via the HOTP/OATH algorithm
defined in RFC 4226. This creates a simple way to protect a web site with
one-time passwords, using any RFC 4226-compliant hardware or software
token device. mod_authn_otp also supports the Mobile-OTP algorithm.

mod_authn_otp supports both event and time based one-time passwords. It
also supports "lingering" which allows the repeated re-use of a previously
used one-time password up to a configurable maximum linger time. This
allows one-time passwords to be used directly in HTTP authentication
without forcing the user to enter a new one-time password for every
page load.

mod_authn_otp supports both basic and digest authentication, and will
auto-synchronize with the user's token within a configurable maximum
offset (auto-synchronization is not supported with digest authentication).

mod_authn_otp is especially useful for setting up protected web sites
that require more security than simple username/password authentication
yet also don't require users to install special VPN software, and is
compatible with software tokens that run on cell phones.

Also included is otptool, a one-time password command line utility. 
otptool can be used on a simple call-out basis to integrate two-factor
authentication into any existing authentication solution. 

%prep
%setup -n %{mod_name}-%{version}

%build
%{configure}
make

%clean
%{__rm} -rf %{buildroot}

%install
%{__install} -d %{buildroot}%{apache_libexecdir}
DESTDIR=%{buildroot} %{makeinstall}

%files
%defattr(-,root,root,-)
%{apache_libexecdir}/%{mod_name}.so
%{_bindir}/otptool
%{_mandir}/man1/otptool.1.gz
%doc CHANGES LICENSE README users.sample

%changelog
* Wed May 28 2014 tchvatal@suse.com
- Fix source download url.
* Sat May 17 2014 archie@dellroad.org
- Update to version 1.1.7
  + Fixed bug where users file could get deleted when using Apache worker MPM (issue #22)
  + Added "OTPAuthFallThrough" to allow fall through to other auth providers (issue #23)
  + Allow "logout" by sending empty password (issue #24)
  + Count PINs against OTPAuthMaxOTPFailure even when they have the wrong length
* Wed Apr  3 2013 archie@dellroad.org
- Update to version 1.1.6
  + Detect errors when writing to the new users.txt file
  + Fix (harmless) bug where new users.txt file was not being closed
- Use correct license string in spec file
- Add copyright notice to spec file
* Fri Nov 30 2012 archie@dellroad.org
- Update to version 1.1.5
  + Allow building on systems without strptime(3) (e.g., Windows)
  + Add support for Apache 2.4.x
* Tue Nov 27 2012 archie@dellroad.org
- Upgrade to version 1.1.4
  + Always allow stale time-based offsets to re-synchronize (issue #14)
  + Added "OTPAuthMaxOTPFailure" to lock accounts after repeated wrong OTP's
  + Fixed bug with "OTPAuthPINAuthProvider" and <AuthnProviderAlias>
  + Added "OTPAuthPINAuthProvider" to allow alternate verification of PINs
  + Added "OTPAuthLogoutOnIPChange" flag to auto-logout on IP address change
* Thu Mar  3 2011 draht@suse.de
- upgrade to build fix release 1.1.1
